<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Extension;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Service\Html\ATS;
use Joomla\CMS\Categories\CategoryServiceInterface;
use Joomla\CMS\Categories\CategoryServiceTrait;
use Joomla\CMS\Component\Router\RouterServiceInterface;
use Joomla\CMS\Component\Router\RouterServiceTrait;
use Joomla\CMS\Extension\BootableExtensionInterface;
use Joomla\CMS\Extension\MVCComponent;
use Joomla\CMS\Factory;
use Joomla\CMS\Fields\FieldsServiceInterface;
use Joomla\CMS\HTML\HTMLRegistryAwareTrait;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Tag\TagServiceInterface;
use Joomla\CMS\Tag\TagServiceTrait;
use Psr\Container\ContainerInterface;

class ATSComponent extends MVCComponent implements
	BootableExtensionInterface, CategoryServiceInterface, TagServiceInterface, FieldsServiceInterface, RouterServiceInterface
{
	use HTMLRegistryAwareTrait;
	use RouterServiceTrait;
	use CategoryServiceTrait
	{
		CategoryServiceTrait::getTableNameForSection insteadof TagServiceTrait;
		CategoryServiceTrait::getStateColumnForSection insteadof TagServiceTrait;
	}
	use TagServiceTrait;

	/** @inheritdoc  */
	public function boot(ContainerInterface $container)
	{
		$db = $container->get('DatabaseDriver');
		$this->getRegistry()->register('ats', new ATS($db));
	}

	/** @inheritdoc  */
	public function getContexts(): array
	{
		Factory::getApplication()->getLanguage()->load('com_ats', JPATH_ADMINISTRATOR);

		return [
			'com_ats.ticket'     => Text::_('COM_ATS_TITLE_TICKETS'),
			'com_ats.categories' => Text::_('JCATEGORY'),
		];
	}

	/** @inheritdoc  */
	public function validateSection($section, $item = null)
	{
		if (!in_array($section, ['categories', 'ticket']))
		{
			return null;
		}

		return $section;
	}

	/** @inheritdoc  */
	protected function getStateColumnForSection(string $section = null)
	{
		return (strtolower($section) === 'category') ? 'published' : 'enabled';
	}

	/** @inheritdoc  */
	protected function getTableNameForSection(string $section = null)
	{
		return (strtolower($section) === 'category') ? 'categories' : 'ats_tickets';
	}
}